Struct VarBitSet

struct VarBitSet(_)

A bit set is a set of bit flags.

Implementations

impl VarBitSet

fn saturated(len: usize) -> Self

Create a bit set of len set values.

impl BitSetLike for VarBitSet

fn new_bitset(max: usize) -> Self
fn len(self: &Self) -> usize
fn test(self: &Self, bit: usize) -> bool
fn set(self: &mut Self, bit: usize)
fn clear(self: &mut Self, bit: usize)
fn count(self: &Self) -> usize

impl Clone for VarBitSet

fn clone(self: &Self) -> VarBitSet

impl Debug for VarBitSet

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for VarBitSet

impl FromIterator for VarBitSet

fn from_iter<T: IntoIterator<Item = usize>>(into_iter: T) -> Self

impl RefUnwindSafe for VarBitSet

impl Send for VarBitSet

impl Sync for VarBitSet

impl Unpin for VarBitSet

impl UnsafeUnpin for VarBitSet

impl UnwindSafe for VarBitSet

impl<T> Any for VarBitSet

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for VarBitSet

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for VarBitSet

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for VarBitSet

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for VarBitSet

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for VarBitSet

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for VarBitSet

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for VarBitSet

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for VarBitSet

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<V, T> VZip for VarBitSet

fn vzip(self: Self) -> V