pub struct LazyValueTree<S: Strategy> { /* private fields */ }Expand description
Represents a value tree that is initialized on the first call to any methods.
This is used to defer potentially expensive generation to shrinking time. It is public only to allow APIs to expose it as an intermediate value.