Proptest Reference Documentation
This is the reference documentation for the proptest API.
For documentation on how to get started with proptest and general usage advice, please refer to the Proptest Book.
Modules
- Defines the
Arbitrarytrait and related free functions and type aliases. - Support for strategies producing fixed-length arrays.
- Strategies for working with bit sets.
- Strategies for generating
boolvalues. - Strategies for generating
charvalues. - Strategies for generating
std::collectionsof values. - Strategies to generate numeric values (as opposed to integers used as bit fields).
- Strategies for generating
std::Optionvalues. - path
stdStrategies for generating [PathBuf] and related path types. - Re-exports the most commonly-needed APIs of proptest.
- Strategies for combining delegate strategies into
std::Results. - Strategies for generating values by taking samples of collections.
- Defines the core traits used by Proptest.
- string
stdStrategies for generating strings and byte strings from regular expressions. - State and functions for running proptest tests.
- Support for combining strategies into tuples.
Macros
- Similar to
assert!from std, but returns a test failure instead of panicking if the condition fails. - Similar to
assert_eq!from std, but returns a test failure instead of panicking if the condition fails. - Similar to
assert_ne!from std, but returns a test failure instead of panicking if the condition fails. - Rejects the test input if assumptions are not met.
- Convenience to define functions which produce new strategies.
- Produce a strategy which picks one of the listed choices.
- Easily define
proptesttests.