Type Alias Mapped
type Mapped = Map<StrategyFor<I>, fn(_: I) -> O>
A normal map from a strategy of I to O.
Stability
This is provided to make documentation more readable. Do not rely on it existing in your own code.
Mappedtype Mapped = Map<StrategyFor<I>, fn(_: I) -> O>
A normal map from a strategy of I to O.
This is provided to make documentation more readable. Do not rely on it existing in your own code.