Probability

Struct Probability 

pub struct Probability(/* private fields */);
A probability in the range [0.0, 1.0] with a default of 0.5.

Implementations

Source

impl Probability

pub fn new(prob: f64) -> Self

Creates a Probability from a f64.

Panics

Panics if the probability is outside interval [0.0, 1.0].

pub fn with<X>(self, and: X) -> (Self, X)

Merges self together with some other argument producing a product type expected by some implementations of A: Arbitrary in A::Parameters. This can be more ergonomic to work with and may help type inference.

pub fn lift<X: Default>(self) -> (Self, X)

Merges self together with some other argument generated with a default value producing a product type expected by some implementations of A: Arbitrary in A::Parameters. This can be more ergonomic to work with and may help type inference.