Struct BoxedStrategy
struct BoxedStrategy<T>(_)
A boxed Strategy trait object as produced by Strategy::boxed().
Strategies of this type afford cheap shallow cloning via reference
counting by using an Arc internally.
Implementations
impl<T> Any for BoxedStrategy<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for BoxedStrategy<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for BoxedStrategy<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Clone for BoxedStrategy<T>
fn clone(self: &Self) -> Self
impl<T> CloneToUninit for BoxedStrategy<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Freeze for BoxedStrategy<T>
impl<T> From for BoxedStrategy<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for BoxedStrategy<T>
impl<T> Send for BoxedStrategy<T>
impl<T> Sync for BoxedStrategy<T>
impl<T> ToOwned for BoxedStrategy<T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> Unpin for BoxedStrategy<T>
impl<T> UnsafeUnpin for BoxedStrategy<T>
impl<T> UnwindSafe for BoxedStrategy<T>
impl<T, U> Into for BoxedStrategy<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for BoxedStrategy<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for BoxedStrategy<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::fmt::Debug> Debug for BoxedStrategy<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: fmt::Debug> Strategy for BoxedStrategy<T>
fn new_tree(self: &Self, runner: &mut TestRunner) -> NewTree<Self>fn boxed(self: Self) -> BoxedStrategy<<Self as >::Value> where Self: Sized + 'static
impl<V, T> VZip for BoxedStrategy<T>
fn vzip(self: Self) -> V