Struct SBoxedStrategy
struct SBoxedStrategy<T>(_)
A boxed Strategy trait object which is also Sync and
Send, as produced by Strategy::sboxed().
Strategies of this type afford cheap shallow cloning via reference
counting by using an Arc internally.
Implementations
impl<T> Any for SBoxedStrategy<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SBoxedStrategy<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SBoxedStrategy<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Clone for SBoxedStrategy<T>
fn clone(self: &Self) -> Self
impl<T> CloneToUninit for SBoxedStrategy<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Freeze for SBoxedStrategy<T>
impl<T> From for SBoxedStrategy<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for SBoxedStrategy<T>
impl<T> Send for SBoxedStrategy<T>
impl<T> Sync for SBoxedStrategy<T>
impl<T> ToOwned for SBoxedStrategy<T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> Unpin for SBoxedStrategy<T>
impl<T> UnsafeUnpin for SBoxedStrategy<T>
impl<T> UnwindSafe for SBoxedStrategy<T>
impl<T, U> Into for SBoxedStrategy<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SBoxedStrategy<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SBoxedStrategy<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::fmt::Debug> Debug for SBoxedStrategy<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: fmt::Debug> Strategy for SBoxedStrategy<T>
fn new_tree(self: &Self, runner: &mut TestRunner) -> NewTree<Self>fn sboxed(self: Self) -> SBoxedStrategy<<Self as >::Value> where Self: Sized + Send + Sync + 'staticfn boxed(self: Self) -> BoxedStrategy<<Self as >::Value> where Self: Sized + 'static
impl<V, T> VZip for SBoxedStrategy<T>
fn vzip(self: Self) -> V